/**
 * Hyperledger Cactus Plugin - Object Store - IPFS
 * Contains/describes the Hyperledger Cactus Object Store IPFS plugin.
 *
 * The version of the OpenAPI document: 2.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
import type { Configuration } from './configuration';
import type { AxiosPromise, AxiosInstance, AxiosRequestConfig } from 'axios';
import globalAxios from 'axios';
import type { RequestArgs } from './base';
import { BaseAPI } from './base';
/**
 *
 * @export
 * @interface GetObjectRequestV1
 */
export interface GetObjectRequestV1 {
    /**
     * The key for the entry to get from the object store.
     * @type {string}
     * @memberof GetObjectRequestV1
     */
    'key': string;
}
/**
 *
 * @export
 * @interface GetObjectResponseV1
 */
export interface GetObjectResponseV1 {
    /**
     * The key that was used to retrieve the value from the object store.
     * @type {string}
     * @memberof GetObjectResponseV1
     */
    'key': string;
    /**
     * The value associated with the requested key in the object store as a string.
     * @type {string}
     * @memberof GetObjectResponseV1
     */
    'value': string;
}
/**
 *
 * @export
 * @interface HasObjectRequestV1
 */
export interface HasObjectRequestV1 {
    /**
     * The key to check for presence in the object store.
     * @type {string}
     * @memberof HasObjectRequestV1
     */
    'key': string;
}
/**
 *
 * @export
 * @interface HasObjectResponseV1
 */
export interface HasObjectResponseV1 {
    /**
     * The key that was used to check the presence of the value in the object store.
     * @type {string}
     * @memberof HasObjectResponseV1
     */
    'key': string;
    /**
     * Date and time encoded as JSON when the presence check was performed by the plugin backend.
     * @type {string}
     * @memberof HasObjectResponseV1
     */
    'checkedAt': string;
    /**
     * The boolean true or false indicating the presence or absence of an object under \'key\'.
     * @type {boolean}
     * @memberof HasObjectResponseV1
     */
    'isPresent': boolean;
}
/**
 *
 * @export
 * @interface SetObjectRequestV1
 */
export interface SetObjectRequestV1 {
    /**
     * The key for the entry to set in the object store.
     * @type {string}
     * @memberof SetObjectRequestV1
     */
    'key': string;
    /**
     * The value that will be associated with the key in the object store.
     * @type {string}
     * @memberof SetObjectRequestV1
     */
    'value': string;
}
/**
 *
 * @export
 * @interface SetObjectResponseV1
 */
export interface SetObjectResponseV1 {
    /**
     * The key that was used to set the value in the object store.
     * @type {string}
     * @memberof SetObjectResponseV1
     */
    'key': string;
}
/**
 * DefaultApi - axios parameter creator
 * @export
 */
export declare const DefaultApiAxiosParamCreator: (configuration?: Configuration) => {
    /**
     *
     * @summary Retrieves an object from the object store.
     * @param {GetObjectRequestV1} getObjectRequestV1 Request body to obtain an object via its key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getObjectV1: (getObjectRequestV1: GetObjectRequestV1, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    /**
     *
     * @summary Checks the presence of an object in the object store.
     * @param {HasObjectRequestV1} hasObjectRequestV1 Request body to check presence of an object under a key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    hasObjectV1: (hasObjectRequestV1: HasObjectRequestV1, options?: AxiosRequestConfig) => Promise<RequestArgs>;
    /**
     *
     * @summary Sets an object in the object store under the specified key.
     * @param {SetObjectRequestV1} setObjectRequestV1 Request body to set an object under a key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    setObjectV1: (setObjectRequestV1: SetObjectRequestV1, options?: AxiosRequestConfig) => Promise<RequestArgs>;
};
/**
 * DefaultApi - functional programming interface
 * @export
 */
export declare const DefaultApiFp: (configuration?: Configuration) => {
    /**
     *
     * @summary Retrieves an object from the object store.
     * @param {GetObjectRequestV1} getObjectRequestV1 Request body to obtain an object via its key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getObjectV1(getObjectRequestV1: GetObjectRequestV1, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<GetObjectResponseV1>>;
    /**
     *
     * @summary Checks the presence of an object in the object store.
     * @param {HasObjectRequestV1} hasObjectRequestV1 Request body to check presence of an object under a key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    hasObjectV1(hasObjectRequestV1: HasObjectRequestV1, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<HasObjectResponseV1>>;
    /**
     *
     * @summary Sets an object in the object store under the specified key.
     * @param {SetObjectRequestV1} setObjectRequestV1 Request body to set an object under a key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    setObjectV1(setObjectRequestV1: SetObjectRequestV1, options?: AxiosRequestConfig): Promise<(axios?: AxiosInstance, basePath?: string) => AxiosPromise<SetObjectResponseV1>>;
};
/**
 * DefaultApi - factory interface
 * @export
 */
export declare const DefaultApiFactory: (configuration?: Configuration, basePath?: string, axios?: AxiosInstance) => {
    /**
     *
     * @summary Retrieves an object from the object store.
     * @param {GetObjectRequestV1} getObjectRequestV1 Request body to obtain an object via its key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    getObjectV1(getObjectRequestV1: GetObjectRequestV1, options?: any): AxiosPromise<GetObjectResponseV1>;
    /**
     *
     * @summary Checks the presence of an object in the object store.
     * @param {HasObjectRequestV1} hasObjectRequestV1 Request body to check presence of an object under a key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    hasObjectV1(hasObjectRequestV1: HasObjectRequestV1, options?: any): AxiosPromise<HasObjectResponseV1>;
    /**
     *
     * @summary Sets an object in the object store under the specified key.
     * @param {SetObjectRequestV1} setObjectRequestV1 Request body to set an object under a key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     */
    setObjectV1(setObjectRequestV1: SetObjectRequestV1, options?: any): AxiosPromise<SetObjectResponseV1>;
};
/**
 * DefaultApi - object-oriented interface
 * @export
 * @class DefaultApi
 * @extends {BaseAPI}
 */
export declare class DefaultApi extends BaseAPI {
    /**
     *
     * @summary Retrieves an object from the object store.
     * @param {GetObjectRequestV1} getObjectRequestV1 Request body to obtain an object via its key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof DefaultApi
     */
    getObjectV1(getObjectRequestV1: GetObjectRequestV1, options?: AxiosRequestConfig): Promise<globalAxios.AxiosResponse<GetObjectResponseV1, any>>;
    /**
     *
     * @summary Checks the presence of an object in the object store.
     * @param {HasObjectRequestV1} hasObjectRequestV1 Request body to check presence of an object under a key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof DefaultApi
     */
    hasObjectV1(hasObjectRequestV1: HasObjectRequestV1, options?: AxiosRequestConfig): Promise<globalAxios.AxiosResponse<HasObjectResponseV1, any>>;
    /**
     *
     * @summary Sets an object in the object store under the specified key.
     * @param {SetObjectRequestV1} setObjectRequestV1 Request body to set an object under a key.
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof DefaultApi
     */
    setObjectV1(setObjectRequestV1: SetObjectRequestV1, options?: AxiosRequestConfig): Promise<globalAxios.AxiosResponse<SetObjectResponseV1, any>>;
}
