/**
 * Since kubo-rpc-client uses ESM only, we can't import it to get types (since we use CJS).
 * To fix this we define required types here, based on their counterparts in kubo-rpc-client.
 */
import type { Multiaddr } from "@multiformats/multiaddr";
import type { MultihashHasher } from "multiformats/hashes/interface";
import type { Agent as HttpAgent } from "http";
import type { Agent as HttpsAgent } from "https";
import type { CID } from "multiformats/cid";
import type { Mtime } from "ipfs-unixfs";
export type MultibaseCodec<Prefix extends string = any> = import("multiformats/bases/interface").MultibaseCodec<Prefix>;
export type BlockCodec<T1 = any, T2 = any> = import("multiformats/codecs/interface").BlockCodec<T1, T2>;
export interface LoadBaseFn {
    (codeOrName: number | string): Promise<MultibaseCodec<any>>;
}
export interface LoadCodecFn {
    (codeOrName: number | string): Promise<BlockCodec<any, any>>;
}
export interface LoadHasherFn {
    (codeOrName: number | string): Promise<MultihashHasher>;
}
export interface IPLDOptions {
    loadBase: LoadBaseFn;
    loadCodec: LoadCodecFn;
    loadHasher: LoadHasherFn;
    bases: Array<MultibaseCodec<any>>;
    codecs: Array<BlockCodec<any, any>>;
    hashers: MultihashHasher[];
}
export interface Options {
    host?: string;
    port?: number;
    protocol?: string;
    headers?: Headers | Record<string, string>;
    timeout?: number | string;
    apiPath?: string;
    url?: URL | string | Multiaddr;
    ipld?: Partial<IPLDOptions>;
    agent?: HttpAgent | HttpsAgent;
}
export type IPFSPath = CID | string;
export interface StatResult {
    cid: CID;
    size: number;
    cumulativeSize: number;
    type: "directory" | "file";
    blocks: number;
    withLocality: boolean;
    local?: boolean;
    sizeLocal?: number;
    mode?: number;
    mtime?: Mtime;
}
/**
 * Connector only needs these methods to work.
 * More methods can be added in the future.
 */
export interface LikeIpfsHttpClientFile {
    read: (ipfsPath: IPFSPath, options?: Record<string, unknown>) => AsyncIterable<Uint8Array>;
    write: (ipfsPath: string, content: string | Uint8Array | Blob | AsyncIterable<Uint8Array> | Iterable<Uint8Array>, options?: Record<string, unknown>) => Promise<void>;
    stat: (ipfsPath: IPFSPath, options?: Record<string, unknown>) => Promise<StatResult>;
}
export declare function isLikeIpfsHttpClientFile(x: unknown): x is LikeIpfsHttpClientFile;
/**
 * Only files API is used
 */
export interface LikeIpfsHttpClient {
    files: LikeIpfsHttpClientFile;
}
export declare function isLikeIpfsHttpClient(x: unknown): x is LikeIpfsHttpClient;
