import type { Express } from "express";
import { LogLevelDesc } from "@hyperledger/cactus-common";
import type { IPluginObjectStore, ICactusPluginOptions, IWebServiceEndpoint, GetObjectRequestV1, GetObjectResponseV1, HasObjectRequestV1, HasObjectResponseV1, SetObjectRequestV1, SetObjectResponseV1 } from "@hyperledger/cactus-core-api";
import { LikeIpfsHttpClient, Options } from "./kubo-rpc-client-types";
export declare const K_IPFS_JS_HTTP_ERROR_FILE_DOES_NOT_EXIST = "HTTPError: file does not exist";
export interface IPluginObjectStoreIpfsOptions extends ICactusPluginOptions {
    readonly logLevel?: LogLevelDesc;
    readonly parentDir: string;
    readonly ipfsClientOrOptions: Options | LikeIpfsHttpClient;
}
export declare class PluginObjectStoreIpfs implements IPluginObjectStore {
    readonly opts: IPluginObjectStoreIpfsOptions;
    static readonly CLASS_NAME = "PluginObjectStoreIpfs";
    private ipfs;
    private readonly log;
    private readonly instanceId;
    private readonly parentDir;
    get className(): string;
    /**
     * We use dynamic import for kubo-rpc-client since it's ESM and we can't import it normally.
     * This methods will load the module and initialize local IPFS client based on ctor arguments.
     */
    private initIpfs;
    /**
     * Get IPFS client or initialize it from constructor args.
     * @returns `LikeIpfsHttpClient` or exception
     */
    private getIpfs;
    constructor(opts: IPluginObjectStoreIpfsOptions);
    getOpenApiSpec(): unknown;
    onPluginInit(): Promise<unknown>;
    registerWebServices(app: Express): Promise<IWebServiceEndpoint[]>;
    getOrCreateWebServices(): Promise<IWebServiceEndpoint[]>;
    getInstanceId(): string;
    getPackageName(): string;
    getKeyPath(req: {
        key: string;
    }): string;
    get(req: GetObjectRequestV1): Promise<GetObjectResponseV1>;
    has(req: HasObjectRequestV1): Promise<HasObjectResponseV1>;
    set(req: SetObjectRequestV1): Promise<SetObjectResponseV1>;
    shutdown(): Promise<void>;
}
